import { isDevMode, Component, Inject, Input, EventEmitter, Output, NgModule, CUSTOM_ELEMENTS_SCHEMA } from '@angular/core';
import { MatDialogRef, MAT_DIALOG_DATA, MatDialogModule } from '@angular/material/dialog';
import { TranslateService, TranslateModule } from '@ngx-translate/core';
import { FormBuilder, ReactiveFormsModule } from '@angular/forms';
import { distinctUntilChanged, debounceTime } from 'rxjs/operators';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatTooltipModule } from '@angular/material/tooltip';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ErrorDialog {
    /**
     * @param {?} dialogRef
     * @param {?} data
     */
    constructor(dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
    }
    /**
     * @return {?}
     */
    onNoClick() {
        this.dialogRef.close();
    }
    /**
     * @param {?} e
     * @param {?=} data
     * @return {?}
     */
    static extractErrorInfo(e, data = {}) {
        return Object.assign(data, {
            showDetails: isDevMode(),
            message: e.message
        });
    }
    /**
     * show error popup if needed
     * @param {?} dialog dialog factory
     * @param {?} e error
     * @param {?=} opts
     * @return {?}
     */
    static openErrorDialog(dialog, e, opts = {}) {
        /** @type {?} */
        let config = Object.assign({
            canBeClosed: true,
            closeOnNavigation: true,
            panelClass: 'dialog-layout',
            disableClose: false,
        }, opts);
        config.data = ErrorDialog.extractErrorInfo(e, config.data);
        console.log('openErrorDialog: ', config);
        /** @type {?} */
        const dialogRef = dialog.open(ErrorDialog, config);
        dialogRef.disableClose = false;
        dialogRef.afterClosed().subscribe((/**
         * @param {?} result
         * @return {?}
         */
        result => {
            console.log('The dialog was closed', result);
        }));
        console.log(e);
        return dialogRef;
    }
}
ErrorDialog.decorators = [
    { type: Component, args: [{
                selector: 'base-error-dialog',
                template: "<h2>ERROR</h2>\n<p>{{data.message}}</p>\n<mat-dialog-content>\n\n  <div class=\"error-info\">\n    <table class=\"info-grid\">\n      <tbody>\n      <tr *ngIf=\"data.status\"><td class=\"label\">Status</td><td class=\"val\">{{data.status}}</td></tr>\n      <tr *ngIf=\"data.code\"><td class=\"label\">Code</td><td class=\"val\">{{data.code}}</td></tr>\n      <tr *ngIf=\"data.link\"><td class=\"label\">Link</td><td class=\"val\">{{data.link}}</td></tr>\n      <tr *ngIf=\"data.request\"><td class=\"label\">Request</td><td class=\"val\">{{data.request}}</td></tr>\n      <tr *ngIf=\"data.operation\"><td class=\"label\">Operation</td><td class=\"val\">{{data.operation}}</td></tr>\n      <tr *ngIf=\"data.component\"><td class=\"label\">Component</td><td class=\"val\">{{data.component}}</td></tr>\n      <tr *ngIf=\"data.developerMessage\"><td class=\"label\">Dev Message:</td><td class=\"val\">{{data.developerMessage}}</td></tr>\n      </tbody>\n    </table>\n  </div>\n\n</mat-dialog-content>\n\n<mat-dialog-actions>\n    <button type=\"button\" class=\"cmd\" matDialogClose mat-raised-button color=\"primary\">Close</button>\n</mat-dialog-actions>\n"
            }] }
];
/** @nocollapse */
ErrorDialog.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
];
if (false) {
    /** @type {?} */
    ErrorDialog.prototype.dialogRef;
    /** @type {?} */
    ErrorDialog.prototype.data;
}
class ErrorDialogHandler {
    /**
     * @param {?} dialog
     */
    constructor(dialog) {
        this.dialog = dialog;
    }
    /**
     * @param {?} error
     * @return {?}
     */
    handleError(error) {
        console.warn("ErrorDialogHandler handleError:", error);
        ErrorDialog.openErrorDialog(this.dialog, error);
    }
}
if (false) {
    /**
     * @type {?}
     * @private
     */
    ErrorDialogHandler.prototype.dialog;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ObjectNotFoundDialogComponent extends ErrorDialog {
    /**
     * @param {?} dialogRef
     * @param {?} data
     */
    constructor(dialogRef, data) {
        super(dialogRef, data);
        this.dialogRef = dialogRef;
        this.data = data;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} dialog
     * @param {?} e
     * @param {?=} opts
     * @return {?}
     */
    static openObjectNotFoundDialog(dialog, e, opts = {}) {
        /** @type {?} */
        let config = Object.assign({
            canBeClosed: true,
            closeOnNavigation: true,
            panelClass: 'dialog-layout',
            disableClose: false,
        }, opts);
        config.data = ObjectNotFoundDialogComponent.extractErrorInfo(e, config.data);
        console.log('openErrorDialog: ', config);
        /** @type {?} */
        const dialogRef = dialog.open(ObjectNotFoundDialogComponent, config);
        dialogRef.disableClose = false;
        return dialogRef;
    }
}
ObjectNotFoundDialogComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-object-not-found-dialog',
                template: "<h2>OBJECT NOT FOUND</h2>\n<p>{{data.message}}</p>\n<mat-dialog-content>\n\n  <div class=\"error-info\">\n    <table class=\"info-grid\">\n      <tbody>\n      <tr *ngIf=\"data.status\"><td class=\"label\">Status</td><td class=\"val\">{{data.status}}</td></tr>\n      <tr *ngIf=\"data.code\"><td class=\"label\">Code</td><td class=\"val\">{{data.code}}</td></tr>\n      <tr *ngIf=\"data.link\"><td class=\"label\">Link</td><td class=\"val\">{{data.link}}</td></tr>\n      <tr *ngIf=\"data.request\"><td class=\"label\">Request</td><td class=\"val\">{{data.request}}</td></tr>\n      <tr *ngIf=\"data.operation\"><td class=\"label\">Operation</td><td class=\"val\">{{data.operation}}</td></tr>\n      <tr *ngIf=\"data.component\"><td class=\"label\">Component</td><td class=\"val\">{{data.component}}</td></tr>\n      <tr *ngIf=\"data.developerMessage\"><td class=\"label\">Dev Message:</td><td class=\"val\">{{data.developerMessage}}</td></tr>\n      </tbody>\n    </table>\n  </div>\n\n</mat-dialog-content>\n\n<mat-dialog-actions>\n  <button mat-raised-button type=\"button\" color=\"accent\" [mat-dialog-close]=\"true\">{{ 'CMD.delete' | translate }}</button>\n  <button mat-button type=\"button\" [mat-dialog-close]=\"false\">{{ 'CMD.cancel' | translate }}</button>\n</mat-dialog-actions>\n"
            }] }
];
/** @nocollapse */
ObjectNotFoundDialogComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
];
if (false) {
    /** @type {?} */
    ObjectNotFoundDialogComponent.prototype.dialogRef;
    /** @type {?} */
    ObjectNotFoundDialogComponent.prototype.data;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BaseDateComponent {
    /**
     * @param {?} translate
     */
    constructor(translate) {
        this.translate = translate;
        this.format = 'day';
        this.formatTip = 'date';
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.translate != null) {
            this.format = this.translatePattern(this.format, 'yyyy-MM-dd');
            if ('false' !== this.formatTip) {
                this.formatTip = this.translatePattern(this.formatTip, 'yyyy-MM-dd HH:mm:ss Z');
            }
        }
    }
    /**
     * @param {?} key
     * @param {?} fallback
     * @return {?}
     */
    translatePattern(key, fallback) {
        /** @type {?} */
        let value = fallback;
        if (BaseDateComponent.FORMAT_NAMES.indexOf(key) !== -1) {
            this.translate.get(BaseDateComponent.RES_PREFIX + key).subscribe((/**
             * @param {?} result
             * @return {?}
             */
            (result) => {
                value = result;
            }));
        }
        return value;
    }
}
BaseDateComponent.RES_PREFIX = 'DateFormat.';
BaseDateComponent.FORMAT_NAMES = ['day', 'date', 'full', 'time', 'year'];
BaseDateComponent.decorators = [
    { type: Component, args: [{
                selector: 'base-date',
                template: "<span *ngIf=\"data\"\n      [matTooltip]=\"formatTip != 'false' ? (data|date:formatTip) : null\">{{data|date:format}}</span>\n"
            }] }
];
/** @nocollapse */
BaseDateComponent.ctorParameters = () => [
    { type: TranslateService }
];
BaseDateComponent.propDecorators = {
    data: [{ type: Input }],
    format: [{ type: Input }],
    formatTip: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    BaseDateComponent.RES_PREFIX;
    /** @type {?} */
    BaseDateComponent.FORMAT_NAMES;
    /** @type {?} */
    BaseDateComponent.prototype.data;
    /** @type {?} */
    BaseDateComponent.prototype.format;
    /** @type {?} */
    BaseDateComponent.prototype.formatTip;
    /**
     * @type {?}
     * @protected
     */
    BaseDateComponent.prototype.translate;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class BaseChangeComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
BaseChangeComponent.decorators = [
    { type: Component, args: [{
                selector: 'base-change',
                template: "<!--<base-date [data]=\"data?.date\"></base-date>-->\n"
            }] }
];
/** @nocollapse */
BaseChangeComponent.ctorParameters = () => [];
BaseChangeComponent.propDecorators = {
    data: [{ type: Input }]
};
if (false) {
    /** @type {?} */
    BaseChangeComponent.prototype.data;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TableSearchComponent {
    /**
     * @param {?} fb
     */
    constructor(fb) {
        this.fb = fb;
        this.changed = new EventEmitter();
        this.debounceTime = 700;
        this.suffix = '*';
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.formGroup = this.fb.group({
            keyword: [null, null]
        });
        this.formGroup.valueChanges.pipe(distinctUntilChanged(), debounceTime(this.debounceTime)).subscribe((/**
         * @param {?} val
         * @return {?}
         */
        val => {
            if (!(val.keyword === null)) {
                val.keyword = val.keyword + this.suffix;
            }
            this.changed.emit(val);
        }));
    }
}
TableSearchComponent.decorators = [
    { type: Component, args: [{
                selector: 'table-search',
                template: "<form [formGroup]=\"formGroup\">\n  <mat-form-field>\n    <mat-label>Suchen</mat-label>\n    <input matInput formControlName=\"keyword\" type=\"search\" nullValue/>\n  </mat-form-field>\n</form>"
            }] }
];
/** @nocollapse */
TableSearchComponent.ctorParameters = () => [
    { type: FormBuilder }
];
TableSearchComponent.propDecorators = {
    changed: [{ type: Output }]
};
if (false) {
    /** @type {?} */
    TableSearchComponent.prototype.changed;
    /** @type {?} */
    TableSearchComponent.prototype.formGroup;
    /** @type {?} */
    TableSearchComponent.prototype.debounceTime;
    /** @type {?} */
    TableSearchComponent.prototype.suffix;
    /**
     * @type {?}
     * @private
     */
    TableSearchComponent.prototype.fb;
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class ChainBaseComp {
}
ChainBaseComp.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    ErrorDialog,
                    ObjectNotFoundDialogComponent,
                    TableSearchComponent,
                    BaseChangeComponent,
                    BaseDateComponent
                ],
                imports: [
                    ReactiveFormsModule,
                    MatFormFieldModule,
                    MatTooltipModule,
                    CommonModule,
                    MatDialogModule,
                    TranslateModule
                ],
                exports: [
                    ErrorDialog,
                    ObjectNotFoundDialogComponent,
                    TableSearchComponent,
                    BaseChangeComponent,
                    BaseDateComponent
                ],
                entryComponents: [
                    ObjectNotFoundDialogComponent,
                    //ValidationResultDialogComponent,
                    ErrorDialog
                ],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { BaseChangeComponent, BaseDateComponent, ChainBaseComp, ErrorDialog, ErrorDialogHandler, ObjectNotFoundDialogComponent, TableSearchComponent };
//# sourceMappingURL=yukawa-chain-base-angular-comp.js.map
